#
# spec file for package libosmocore
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libosmocore
Version:        1.3.0
Release:        lp152.1.3
Summary:        The Open Source Mobile Communications Core Library
License:        GPL-2.0-only AND GPL-2.0-or-later AND LGPL-2.1-or-later AND AGPL-3.0-or-later
Group:          Productivity/Telephony/Utilities
URL:            https://osmocom.org/projects/libosmocore/wiki/Libosmocore
Source:         %name-%version.tar.xz
BuildRequires:  automake >= 1.6
BuildRequires:  libtool >= 2
BuildRequires:  lksctp-tools-devel
BuildRequires:  pkg-config >= 0.20
BuildRequires:  python3
BuildRequires:  xz
BuildRequires:  pkgconfig(gnutls) >= 2.12.0
BuildRequires:  pkgconfig(libpcsclite)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(talloc) >= 2.0.1

%description
libosmocore is a package with various utility functions that were
originally developed as part of the OpenBSC project, but which are of
a more generic nature and thus useful to (at least) other programs
that Osmocom develops w.r.t. mobile communications.

There is no clear scope of it. It simply houses all code shared
between OsmocomBB and OpenBSC to avoid code duplication.

%package tools
Summary:        GSM utilities from the osmocore project
License:        GPL-2.0-only AND GPL-2.0-or-later AND LGPL-3.0-or-later AND AGPL-3.0-or-later
Group:          Productivity/Telephony/Utilities
Provides:       %name-utils = %version-%release

%description tools
libosmocore is a package with various utility functions that were
originally developed as part of the OpenBSC project.

This package contains a program for frequency calculation for GSM
called "osmo-arfcn", and a program called "osmo-auc-gen" that is used
for testing GSM authentication.

%package -n libosmocodec0
Summary:        GSM 06.10, 06.20, 06.60, 06.90 codec library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmocodec0
The libosmocodec library contains an implementation of multiple
GSM codecs:

* GSM 06.10 Full Rate (FR) codec
* GSM 06.20 Half Rate (HR) codec
* GSM 06.60 Enhanced Full Range (EFR) codec
* GSM 06.90 Adaptive Multi-Rate (AMR) codec

%package -n libosmocodec-devel
Summary:        Development files for the Osmocom GSM codec library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmocodec0 = %version

%description -n libosmocodec-devel
The libosmocodec library contains an implementation of multiple
GSM codecs.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmocodec.

%package -n libosmocoding0
Summary:        GSM/GPRS/EDGE transcoding routines library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmocoding0
libosmocoding is a library which provides GSM, GPRS and EDGE
transcoding routines.

The following data types are currently supported: xCCH, PDTCH (CS 1-4
and MCS 1-9), TCH/FR, TCH/HR, TCH/AFS, RCH/AHS, RACH and SCH.

%package -n libosmocoding-devel
Summary:        Development files for the Osmocom transcoding library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmocoding0 = %version
Requires:       libosmocore-devel = %version

%description -n libosmocoding-devel
libosmocoding is a library which provides GSM, GPRS and EDGE
transcoding routines.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmocoding.

%package -n libosmocore12
Summary:        Osmocom core library
# crc16.c has GPL2-only clauses, the rest (*.c) is GPL-2.0+
License:        GPL-2.0-only AND GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmocore12
libosmocore is a library with various utility functions shared
between OpenBSC and OsmocomBB.

%package -n libosmocore-devel
Summary:        Development files for the Osmocom core library
# crc16.h has GPL2-only clauses, the rest (*.h) is GPL-2.0+
License:        GPL-2.0-only AND GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmocore12 = %version
Requires:       libtalloc-devel

%description -n libosmocore-devel
libosmocore is a library with various utility functions shared
between OpenBSC and OsmocomBB.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmocore.

%package -n libosmoctrl0
Summary:        Osmocom SNMP-like control interface library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmoctrl0
libosmocore is a package with various utility functions that were
originally developed as part of the OpenBSC project.

libosmoctrl is an SNMP-like control interface. In contrast to the VTY
interface, the control interface is meant to be used by programs.

%package -n libosmoctrl-devel
Summary:        Osmocom control interface library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmocore-devel = %version
Requires:       libosmoctrl0 = %version
Requires:       libosmovty-devel = %version

%description -n libosmoctrl-devel
libosmoctrl is an SNMP-like control interface. In contrast to the VTY
interface, the control interface is meant to be used by programs.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmoctrl.

%package -n libosmogb9
Summary:        Osmocom GPRS Gb Interface (NS/BSSGP) library
License:        AGPL-3.0-or-later
Group:          System/Libraries

%description -n libosmogb9
libosmocore is a package with various utility functions that were
originally developed as part of the OpenBSC project.

The libosmogb library contains a GPRS BSSGP protocol implementation.

%package -n libosmogb-devel
Summary:        Development files for the Osmocom GPRS Gb interface library
License:        AGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmocore-devel = %version
Requires:       libosmogb9 = %version
Requires:       libosmogsm-devel = %version

%description -n libosmogb-devel
The libosmogb library contains a GPRS BSSGP protocol implementation.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmogb.

%package -n libosmogsm13
Summary:        Osmocom GSM utility library
License:        GPL-2.0-or-later AND AGPL-3.0-or-later
Group:          System/Libraries

%description -n libosmogsm13
libosmocore is a package with various utility functions that were
originally developed as part of the OpenBSC project.

The libosmogsm library in particular is a collection of common code
used in various GSM related sub-projects inside the Osmocom family of
projects. It includes A5/1 and A5/2 ciphers, COMP128v1, a LAPDm
implementation, a GSM TLV parser, SMS utility routines as well as
protocol definitions for a series of protocols.

%package -n libosmogsm-devel
Summary:        Development files for the Osmocom GSM utility library
License:        GPL-2.0-or-later AND AGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmocore-devel = %version
Requires:       libosmogsm13 = %version

%description -n libosmogsm-devel
The libosmogsm library in particular is a collection of common code
used in various GSM related sub-projects inside the Osmocom family of
projects. It includes A5/1 and A5/2 ciphers, COMP128v1, a LAPDm
implementation, a GSM TLV parser, SMS utility routines as well as
protocol definitions for a series of protocols.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmogsm.

%package -n libosmosim0
Summary:        Osmocom SIM card related utility library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmosim0
libosmocore is a package with various utility functions that were
originally developed as part of the OpenBSC project.

The libosmosim library in particular contains routines for SIM card
access.

%package -n libosmosim-devel
Summary:        Development files for the Osmocom SIM card utility library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmocore-devel = %version
Requires:       libosmosim0 = %version

%description -n libosmosim-devel
The libosmosim library in particular contains routines for SIM card
access.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmosim.

%package -n libosmovty4
Summary:        Osmocom VTY interface library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmovty4
libosmocore is a package with various utility functions that were
originally developed as part of the OpenBSC project.

The libosmovty library implements the interactive command-line on the
VTY (Virtual TTY), as well as configuration file parsing.

%package -n libosmovty-devel
Summary:        Development files for the Osmocom VTY interface library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmocore-devel = %version
Requires:       libosmovty4 = %version

%description -n libosmovty-devel
The libosmovty library implements the interactive command-line on the
VTY (Virtual TTY), as well as configuration file parsing.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmovty.

%package -n libosmousb0
Summary:        Osmocom USB library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmousb0
libosmocore is a package with various utility functions that were
originally developed as part of the OpenBSC project.

The libosmosub library in particular contains routines for USB device
access via libusb-1.0, integrated into the libosmocore select event loop.

%package -n libosmousb-devel
Summary:        Development files for the Osmocom USB library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmocore-devel = %version
Requires:       libosmousb0 = %version
Requires:       libusb-1_0-devel

%description -n libosmousb-devel
The libosmosub library in particular contains routines for USB device
access via libusb-1.0, integrated into the libosmocore select event loop.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmousb.

%prep
%autosetup -p1

%build
echo "%version" >.tarball-version
autoreconf -fiv
%configure \
    --enable-shared \
    --disable-static \
    --includedir="%_includedir/%name"
make %{?_smp_mflags}

%install
b="%buildroot"
make %{?_smp_mflags} install DESTDIR="$b"
find "$b/%_libdir" -type f -name "*.la" -delete

%check
make %{?_smp_mflags} check || (find . -name testsuite.log -exec cat {} +)

%post   -n libosmocodec0 -p /sbin/ldconfig
%postun -n libosmocodec0 -p /sbin/ldconfig
%post   -n libosmocoding0 -p /sbin/ldconfig
%postun -n libosmocoding0 -p /sbin/ldconfig
%post   -n libosmocore12 -p /sbin/ldconfig
%postun -n libosmocore12 -p /sbin/ldconfig
%post   -n libosmoctrl0 -p /sbin/ldconfig
%postun -n libosmoctrl0 -p /sbin/ldconfig
%post   -n libosmogb9 -p /sbin/ldconfig
%postun -n libosmogb9 -p /sbin/ldconfig
%post   -n libosmogsm13 -p /sbin/ldconfig
%postun -n libosmogsm13 -p /sbin/ldconfig
%post   -n libosmosim0 -p /sbin/ldconfig
%postun -n libosmosim0 -p /sbin/ldconfig
%post   -n libosmovty4 -p /sbin/ldconfig
%postun -n libosmovty4 -p /sbin/ldconfig
%post   -n libosmousb0 -p /sbin/ldconfig
%postun -n libosmousb0 -p /sbin/ldconfig

%files tools
%_bindir/osmo-*

%files -n libosmocodec0
%_libdir/libosmocodec.so.0*

%files -n libosmocodec-devel
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/codec/
%_libdir/libosmocodec.so
%_libdir/pkgconfig/libosmocodec.pc

%files -n libosmocoding0
%_libdir/libosmocoding.so.0*

%files -n libosmocoding-devel
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/coding/
%_libdir/libosmocoding.so
%_libdir/pkgconfig/libosmocoding.pc

%files -n libosmocore12
%_libdir/libosmocore.so.12*

%files -n libosmocore-devel
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/core/
%_libdir/libosmocore.so
%_libdir/pkgconfig/libosmocore.pc
%_datadir/aclocal/osmo_ax_code_coverage.m4
%_datadir/aclocal/osmo_ac_code_coverage.m4

%files -n libosmoctrl0
%_libdir/libosmoctrl.so.0*

%files -n libosmoctrl-devel
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/ctrl/
%_libdir/libosmoctrl.so
%_libdir/pkgconfig/libosmoctrl.pc

%files -n libosmogb9
%_libdir/libosmogb.so.9*

%files -n libosmogb-devel
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/gprs/
%_libdir/libosmogb.so
%_libdir/pkgconfig/libosmogb.pc

%files -n libosmogsm13
%_libdir/libosmogsm.so.13*

%files -n libosmogsm-devel
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/gsm/
%_includedir/%name/osmocom/crypt/
%_libdir/libosmogsm.so
%_libdir/pkgconfig/libosmogsm.pc

%files -n libosmosim0
%_libdir/libosmosim.so.0*

%files -n libosmosim-devel
%dir %_includedir/%name
%dir %_includedir/%name/osmocom/
%_includedir/%name/osmocom/sim/
%_libdir/libosmosim.so
%_libdir/pkgconfig/libosmosim.pc

%files -n libosmovty4
%_libdir/libosmovty.so.4*

%files -n libosmovty-devel
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/vty/
%_includedir/%name/osmo-release.mk
%_libdir/libosmovty.so
%_libdir/pkgconfig/libosmovty.pc

%files -n libosmousb0
%defattr(-,root,root)
%_libdir/libosmousb.so.0*

%files -n libosmousb-devel
%defattr(-,root,root)
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/usb/
%_libdir/libosmousb.so
%_libdir/pkgconfig/libosmousb.pc

%changelog
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.3.0
  * add osmo_sockaddr_str_cmp()
  * misc logging/vty fixes
  * fix OSMO_SOCKADDR_STR_FMT for IPv6
  * GPRS/BSSGP: introduce bssgp_bvc_ctx_free()
  * gsm_04_08.h: Introduce API osmo_gsm48_rfpowercap2powerclass()
  * gsm0508: add functions to calculate beginning of a block
  * socket: Introduce API osmo_sock_init2_multiaddr()
  * vty: Optionally Set/replace cfg file during cmd 'write file'
  * gsup: add OSMO_GSUP_SUPPORTED_RAT_TYPES_IE and
    OSMO_GSUP_CURRENT_RAT_TYPE_IE
  * tdef: Introduce API osmo_tdef_set()
  * Introduce BTS_FEAT_ETWS_PN for communicating ETWS PN capability
  * context: Add support for [per-thread] global talloc contexts
  * add vty logp command to echo on all log targets
- Add subpackges for the Osmocom USB library
* Wed Aug 14 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.2.0
  * GSUP: add inter-MSC handover related msgs and IEs
  * NS: Add support for GPRS NS IP Sub-Network-Service (SNS)
  * BSSMAP: add messages for inter-BSC and inter-MSC Handover
  * Add VTY and CTRL port numbers for OsmoCBC (Cell Broadcast Centre)
  * CBSP (Cell Broadcast Service Protocol; 3GPP TS 48.049) support
  * Add Cell Broadcast related definitions from 3GPP TS 23.041
  * Add MO-FALLBACK-VALUE SGsAP IE
- Removed 0001-gsm_23_003.h-add-GSM23003_IMEI_NUM_DIGITS_NO_CHK.patch
  (merged)
* Tue Feb 19 2019 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * 0001-gsm_23_003.h-add-GSM23003_IMEI_NUM_DIGITS_NO_CHK.patch
    Needed for osmo-hlr 1.0.0
* Thu Jan 31 2019 mardnh@gmx.de
- Update to version 1.0.1
  Bugfix release:
  * when msgb_wrap_with_TL() was introduced as an inline function
    with exactly the same name as in openbsc. With this subsequent
    change we make sure the libosmocore function has a different
    name and doesn't clash.
* Sat Jan 19 2019 mardnh@gmx.de
- Update to version 1.0.0
  * GSMTAP: add SIM sub_types
  * gsm0808: inter-bsc HO messages: add missing BSSMAP header, x4
  * gsm0808: implement BSSMAP Classmark Request
  * logging vty: rewrite 'logging level' vty cmd generation
  * logging vty: deprecate the 'everything' keyword
  * logging vty: deprecate 'all', introduce 'force-all'
  * logging vty: add 'logging level set-all <level>'
  * bssgp: introduce flush queue functions
  * import oap_client into libosmogsm
  * SGsAP protocol definitions (header + C file)
  * GSUP/SMS: introduce MO-/MT-FORWARD-SM messages
  * GSUP/SMS: introduce READY-FOR-SM message
  * GSMTAP: add definitions for new LTE RRC channels
  * GSMTAP: add definitions for LTE NAS subtypes
  * LCLS, TS 29.205: add GCR routines
  * LCLS, TS 48.008: add GCR IE encoding/decoding
  * GSUP: add CHECK-IMEI message
  * vty: Make TCP port configurable and introduce
    telnet_init_default
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Upgrade to new snapshot 0.13.0~194 (6adffb95734)
  * 'lo and behold, 0.12.1 is not sufficient to build
    libosmo-abis 0.5.1 requiring ">= 0.12.0"
  * socket: do not set SO_REUSEADDR for IPPROTO_UDP
  * socket: add flag to enforce SO_REUSEADDR on UDP sockets
  * gsmtap_util: make sure SO_REUSEADDR is applied for GSMTAP
  * Add RSPRO support to IPA and logging definitions
  * Update 3GPP TS 08.08 Cause handling
  * Update GSM0808_LCLS enums
* Mon Aug 20 2018 mardnh@gmx.de
- Update to new upstream release 0.12.1
  * GnuTLS fall-back for obtaining randomness
  * support for three-digit MNC throughout the code-base
  * add talloc introspection via VTY
  * tighter CRTL input parsing
  * stricter VTY config file parsing
  * allow to print only basename of source code file in logging
  * print log level with color-keying of the level name
  See the following URLs for complete changelogs:
  http://git.osmocom.org/libosmocore/plain/debian/changelog?h=0.12.1
  http://git.osmocom.org/libosmocore/plain/debian/changelog?h=0.12.0
  http://git.osmocom.org/libosmocore/plain/debian/changelog?h=0.11.0
- Remove patch:
  * osmo-pkgconfig.diff (fixed upstream)
* Thu Mar 22 2018 jengelh@inai.de
- Add libosmocoding-devel => libosmocore-devel dependency
  because the .h file #includes, but the .pc file is missing it.
* Wed Mar 14 2018 jengelh@inai.de
- Add missing BuildRequires on python
* Wed Dec 27 2017 jengelh@inai.de
- Update to new upstream release 0.10.2
  * GPRS: print remote state info for NS peer
  * ctrl: allow more nodes than those in enum ctrl_node_type
  * fsm: Enforce FSM and FSM instance names are valid osmocom
    identifiers
  * rate_ctr: Enforce counter (and ctr_group) names are valid
    identifiers
  * Convert lib-internal rate_ctr from '.' separator to ':'
    separator
  * GPRS: add vty command to show only persistent NS
* Mon Oct  2 2017 jengelh@inai.de
- Update to new upstream snapshot 0.9.6.400
  * vty: install 'exit', 'end',... commands on *all* nodes
  * osmo-auc-gen: umts: add --ind-len arg
  * osmo-auc-gen: umts: add --ind arg
  * Add osmo_gprs_{ul,dl}_block_size_{bits,bytes} functions
  * BSSGP: add function to reset all PTP BVC
  * GSUP: define default GSUP port as 4222
  * gsup: Add encoding/decoding for the pdp charging characteristics
  * Add missing BSSGP cause values
  * gsm0808: fix length check of the element decoder functions
  * Add header file with definitions for GSM TS 04.14 / 3GPP TS 44.014
  * Fix wrongful GSM FR codec SID frame detection in DTX.
  * Distinguish between unsupported and invalid MCS
* Fri Apr 28 2017 jengelh@inai.de
- Update to new upstream snapshot 0.9.6.193
  * fix: DLGSUP logging category "unusable"
  * ph_data_param struct changed / Extend L1SAP PH-DATA with
    measurement information.
  * Size of ph_tch_param struct changed / Extend with RTP Marker
  * Size of struct log_target changed / Extend with GSMTAP
  * Internal API for GPRS cipher implementors updated to
    accommodate for arbitrary key lengths.
  * Extend L1SAP PH-DATA with presence information
  * Fix the counter index after the NS reset.
  * Fix rate_ctr attribute for GPRS NS counters.
- Remove test.diff (no longer applicable)
* Sat Jul 30 2016 jengelh@inai.de
- Update to new upstream snapshot 0.9.0.212
  * Add support for SI2quater messages
  * Add basic EARFCN support
  * Add vty command to explicitly reset given BVCI
  * Add function to make Uplink Measurement
  * Add GEA3 & GEA4 ciphers
* Fri Mar 11 2016 jengelh@inai.de
- reenable bigendian builds as GSM IE code was fixed upstream
  during 2015
- Update to new upstream snapshot 0.9.0.91
  * log: Add conditional logging based on log_check_level
  * Add byte printing macros
  * vty: add bind command for telnet vty line
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream snapshot 0.9.0.58
  * Add bitvector functions and APN conversion functions
- Add test.diff to resolve compiler warning
* Wed Dec 23 2015 jengelh@inai.de
- Update to new upstream release 0.9.0
  * ipaccess: add OAP proto_ext (in design).
  * stats: Report stat item values
  * stats: Implement timer based reporting
  * stats/vty: Add stats configuration
  * stat/vty: Add vty_out_statistics_full to show all statistics
  * stats: Add vty_out_stat_item_group
  * LaPDm: Refuse SUSPEND/RESUME/RECONNECT in BTS mode
  * ns: Force a defined state when sending NS RESET
- Drop osmo-symbols.diff (solved better upstream),
  osmo-talloc.diff, osmo-talloc2.diff, osmo-talloc3.diff (solved
  upstream)
* Thu Sep 10 2015 jengelh@inai.de
- Update to new upstream release 0.8.3
  * Add G-RNTI derived TLLI types defined in 23.003
  * vty: Change API to have node installation be done by int
  * ipa: Properly parse LV stream of a ID_GET request
  * Add APN utility function to libosmogsm
  * gsm: Add A5/3-4 cipher support
  * bssgp: Handle BSSGP STATUS messages
- Add osmo-symbols.diff
* Sun Mar  1 2015 jengelh@inai.de
- Update to new upstream release 0.8.0
  * new Osmocom SIM card library
- Remove 0001-utils-resolve-compiler-warnings-on-implicit-declarat.patch,
  libosmocore_0_7_0_avoid_smscb_test_failure.patch,
  osmo-kasumi.diff, osmo-version.diff (no longer needed x4),
  rework osmo-talloc2.diff and add osmo-talloc3.diff after upstream
  conversion. Add osmo-pkgconfig.diff.
* Wed Feb 18 2015 normand@linux.vnet.ibm.com
- remove the previous patch about  ppc/ppc64 architectures
  as upstream suggesting that known to be not supported
  so explicitely add ExcludeArch in spec file.
* Wed Feb 18 2015 normand@linux.vnet.ibm.com
- avoid smscb test failure on ppc/ppc64 architectures
  with libosmocore_0_7_0_avoid_smscb_test_failure.patch
* Thu Oct  2 2014 jengelh@inai.de
- Update to new upstream release 0.7.0
  * No changelog was provided
  * osmocore gained GPRS NS interface support, and now provides a
  control interface library (libosmoctrl)
- Add osmo-kasumi.diff to fix link failure during `make check`
* Mon Jul 21 2014 jengelh@inai.de
- Update to new upstream release 0.6.6
  * No changelog was provided
- Remove 0001-osmo-arfcn-Return-something-from-the-method.patch,
  0002-utils-avoid-breaking-strict-aliasing.patch (no longer needed)
* Sun Jun  2 2013 jengelh@inai.de
- Update to new upstream release 0.6.0
  * No changelog was provided
- Add 0001-osmo-arfcn-Return-something-from-the-method.patch
  from upstream to provide fix for rpmlint errors
- Add 0001-utils-resolve-compiler-warnings-on-implicit-declarat.patch,
  0002-utils-avoid-breaking-strict-aliasing.patch to fix rpmlint
  warnings
* Sun Feb 17 2013 jengelh@inai.de
- Initial package (version 0.5.3) for build.opensuse.org
* Mon Oct 10 2011 jengelh@medozas.de
- Initial prototype (version 0.3.10)
